@@ -29,7 +29,7 @@ inprod <- function(fdobj1, fdobj2=NULL, Lfdobj1=int2Lfd(0), Lfdobj2=int2Lfd(0),
 #  A matrix of NREP1 by NREP2 of inner products for each possible pair
 #  of functions.
 
-#  Last modified 5 May 2009
+#  Last modified 2 February 2010
 
 #  Check FDOBJ1 and get no. replications and basis object
 
@@ -171,14 +171,14 @@ for (irng  in  2:nrng) {
         fx2 <- matrix(wtd,dim(wtd)[1],dim(fx2)[2]) * fx2
     }
     s[1,,] <- width*crossprod(fx1,fx2)/2
-    tnm <- 0.5
-    j <- 1
+    tnm  <- 0.5
+    iter <- 1
 
     #  now iterate to convergence
 
     for (iter in 2:JMAX) {
         tnm <- tnm*2
-        if (j == 2) {
+        if (iter == 2) {
             x <- mean(rngi)
         } else {
             del <- width/tnm
