@@ -534,7 +534,7 @@ fngrad.smooth.monotone <- function(yi, argvals, zmat, wtvec, cveci, lambda,
   yroot  <- yi*wtroot
   xroot  <- xmat*wtrtmt
   #  compute regression coefs.
-  betai  <- lsfit(xmat, yi, wtvec, int=FALSE)$coef
+  betai  <- lsfit(xmat, yi, wtvec, intercept=FALSE)$coef
   #  update fitted values
   yhat   <- xmat %*% betai
   #  update residuals and function values
